@@ -3,16 +3,12 @@ from data_manipulation import (
     beautifulsoup_,
     django_,
     geopandas_,
+    mysql_connector_python_,
     pandas_,
     psycopg2_,
     pyspark_,
 )
 
-from ._version import get_versions
-
-__version__ = get_versions()["version"]
-del get_versions
-
 from . import _version
 
 __version__ = _version.get_versions()["version"]
